You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cayenne.apache.org by aa...@apache.org on 2006/05/07 17:40:14 UTC

svn commit: r404784 - in /incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin: cvs-snapshot.pl maven-build.sh nightly-build.pl

Author: aadamchik
Date: Sun May  7 08:40:10 2006
New Revision: 404784

URL: http://svn.apache.org/viewcvs?rev=404784&view=rev
Log:
fixing nightly build scripts to use SVN

Removed:
    incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/cvs-snapshot.pl
Modified:
    incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/maven-build.sh
    incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/nightly-build.pl

Modified: incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/maven-build.sh
URL: http://svn.apache.org/viewcvs/incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/maven-build.sh?rev=404784&r1=404783&r2=404784&view=diff
==============================================================================
--- incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/maven-build.sh (original)
+++ incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/maven-build.sh Sun May  7 08:40:10 2006
@@ -5,7 +5,7 @@
 CAYENNE_ANT=$CAYENNE_BASE/cayenne-ant
 
 cd $CAYENNE_BASE
-cvs up
+svn up
 
 cd $CAYENNE_ANT
 ant clean

Modified: incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/nightly-build.pl
URL: http://svn.apache.org/viewcvs/incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/nightly-build.pl?rev=404784&r1=404783&r2=404784&view=diff
==============================================================================
--- incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/nightly-build.pl (original)
+++ incubator/cayenne/main/trunk/cayenne/cayenne-ant/bin/nightly-build.pl Sun May  7 08:40:10 2006
@@ -13,14 +13,14 @@
 #   6. Entry in $HOME/.cayenne/connection.properties for "nightly-test"
 #
 # Command line:
-#     nightly-build.pl -d cvsroot [-u] [-n] [-m email@example.com] 
+#     nightly-build.pl -d svnroot [-u] [-n] [-m email@example.com] 
 #            -u - upload build and test results to the server
 #            -n - skip CVS checkout (used mostly for debugging)
 #            -d - CVSROOT to use for code checkout
 #
 # Crontab:
 #
-#     2 5 * * * export CVS_RSH=ssh; /fullpathto/nightly-build.pl -d :ext:xyz@cvs.sourceforge.net:/cvsroot/cayenne [-u] [-m email@example.com]  2>&1 > /dev/null
+#     2 5 * * * export CVS_RSH=ssh; /fullpathto/nightly-build.pl -d http://svn.apache.org/repos/asf/incubator/cayenne/main/trunk/cayenne/ [-u] [-m email@example.com]  2>&1 > /dev/null
 #
 
 use strict;
@@ -144,26 +144,13 @@
 		mkpath($cayenne_src, 1, 0711) or die_with_email("Can't create build directory: $!\n");
 		chdir $cayenne_src or die_with_email("Can't change to $cayenne_src: $!\n");
 
-		my $status = 0;
-                my $i = 0;
-                 
-                # cvs checkouts are unreliable...give it a few tries
-		$ENV{"CVS_RSH"} = "ssh";
-		for($i = 0; $i < 5; $i++) {
-                	$status = run_command(
-			" cvs" . 
-			" -z3" .
-			" -q" .
-			" -d$opt_d" .
+		my $status = run_command(
+			" svn" . 
 			" export" .
-			" -D" .
-			" \"1 minute ago\"" .
-			" cayenne");
-                    print_line("CVS checkout status: $status\n");
-                    last unless $status;
-                    sleep 120;
-                }
-		die_with_email("CVS checkout failed, return status: $status, attempts: $i\n") if $status;
+			" $opt_d");
+            print_line("SVN checkout status: $status\n");
+
+		die_with_email("SVN checkout failed, return status: $status, attempts: $i\n") if $status;
 	}
 }
@@ -13,14 +13,14 @@
 #            -u - upload build and test results to the server
-#            -n - skip CVS checkout (used mostly for debugging)
-#            -d - CVSROOT to use for code checkout
+#            -n - skip SVN checkout (used mostly for debugging)
+#            -d - SVN path
 #
 # Crontab: